
# THIS FILE IS GENERATED FROM PYART SETUP.PY
short_version = '1.10.2'
version = '1.10.2'
full_version = '1.10.2'
git_revision = '71862853d750f6202883ea7567eb42a6704561db'
release = True

if not release:
    version = full_version
